==> v2.0.0-beta.zip: convoypanel/README.md <==
![Banner Logo](https://imgur.com/oAGZ7fb.png)

![GitHub Workflow Status](https://img.shields.io/github/workflow/status/convoypanel/panel/Tests?label=Tests)
![Discord](https://img.shields.io/discord/746612878261616700?label=Discord&logo=Discord&logoColor=white)
![GitHub Releases](https://img.shields.io/github/downloads/convoypanel/panel/latest/total)
[![FOSSA Status](https://app.fossa.com/api/projects/git%2Bgithub.com%2FConvoyPanel%2Fpanel.svg?type=shield)](https://app.fossa.com/projects/git%2Bgithub.com%2FConvoyPanel%2Fpanel?ref=badge_shield)

# Convoy
Convoy is a modern and performant KVM server management panel for hosting businesses. It's built with PHP and React and proven technology like Proxmox, making it easier to drop in Convoy.

Stop paying hundreds of dollars for unreliable and slow software. Subscribe to a license to use Convoy today for $6/node/mo

![Screenshot of Convoy](https://imgur.com/pFj0kvO.png)

## Documentation
* [Panel Documentation](https://docs.convoypanel.com)
* [Discord Community](https://discord.convoypanel.com)

## Acknowledgements

Convoy wouldn't have been possible without these organizations and people

* Advin Servers - provided several development servers (at least $200 of hardware) to help me develop this SaaS
* Kjartann - donated $250 to support Convoy development and encouraged me to keep on working on this panel!
* Pterodactyl Panel - provided the architecture and a lot of backend/boilerplate code for Convoy.
* FastKVM.EU - for reporting bugs and testing the panel

## License
Convoy is licensed under the Business Source License. Production use of Convoy without an active license from Performave is strictly disallowed.

[![FOSSA Status](https://app.fossa.com/api/projects/git%2Bgithub.com%2FConvoyPanel%2Fpanel.svg?type=large)](https://app.fossa.com/projects/git%2Bgithub.com%2FConvoyPanel%2Fpanel?ref=badge_large)

==> v2.0.1-beta.zip: convoypanel/README.md <==
![Banner Logo](https://imgur.com/oAGZ7fb.png)

![GitHub Workflow Status](https://img.shields.io/github/workflow/status/convoypanel/panel/Tests?label=Tests)
![Discord](https://img.shields.io/discord/746612878261616700?label=Discord&logo=Discord&logoColor=white)
![GitHub Releases](https://img.shields.io/github/downloads/convoypanel/panel/latest/total)
[![FOSSA Status](https://app.fossa.com/api/projects/git%2Bgithub.com%2FConvoyPanel%2Fpanel.svg?type=shield)](https://app.fossa.com/projects/git%2Bgithub.com%2FConvoyPanel%2Fpanel?ref=badge_shield)

# Convoy
Convoy is a modern and performant KVM server management panel for hosting businesses. It's built with PHP and React and proven technology like Proxmox, making it easier to drop Convoy in an existing system.

Stop paying hundreds of dollars for unreliable and slow software. Subscribe to a license to use Convoy today for $6/node/mo

![Screenshot of Convoy](https://imgur.com/pFj0kvO.png)

## Documentation
* [Panel Documentation](https://docs.convoypanel.com)
* [Discord Community](https://discord.convoypanel.com)

## Acknowledgements

Convoy wouldn't have been possible without these organizations and people

* Advin Servers - provided several development servers (at least $200 of hardware) to help me develop this SaaS
* Kjartann - donated $250 to support Convoy development and encouraged me to keep on working on this panel!
* Pterodactyl Panel - provided the architecture and a lot of backend/boilerplate code for Convoy.
* FastKVM.EU - for reporting bugs and testing the panel

## License
Convoy is licensed under the Business Source License. Production use of Convoy without an active license from Performave is strictly disallowed.

[![FOSSA Status](https://app.fossa.com/api/projects/git%2Bgithub.com%2FConvoyPanel%2Fpanel.svg?type=large)](https://app.fossa.com/projects/git%2Bgithub.com%2FConvoyPanel%2Fpanel?ref=badge_large)
